==> plonetheme.intk-1.1.linux-x86_64.tar.gz: var/plone4_dev/Python-2.6/lib/python2.6/site-packages/plonetheme/intk/browser/javascripts/mason.js <==
//TODO: keep an array of all images and wait for all of them to check in before running masonry

jq(window).ready(function(){
    jq('.template-search .searchResults .tileItem').css({"opacity": "0"});
    setTimeout(function(){
        jq('.template-search .searchResults').masonry({columnWidth: 100, animate:true});
        jq('.template-search .searchResults .tileItem').animate({"opacity": "1"}, 200);
    }, 1000);
});

jq(window).ready(function(){
    jq('.template-intk_folder_view #content .tileItem').css({"opacity": "0"});
    setTimeout(function(){
        jq('.template-intk_folder_view #masonContainer').masonry({columnWidth: 100, animate:true});
        jq('.template-intk_folder_view #masonContainer .tileItem').animate({"opacity": "1"}, 200);
    }, 1000);
});

jq(function(){
    jq('#portal-searchbox').hover(
                function() {
                    var title = jq('#parent-fieldname-title').text();
                    if(title != "")
                    {
                        jq('#portal-searchbox #nolivesearchGadget').attr('value', jq.trim(title));
                    }
                    jq(this).stop().css({"opacity": "1"});
                },
                function() {
                    if(jq('#portal-searchbox #nolivesearchGadget:focus').length == 0)
                    {
                        jq(this).stop().animate({"opacity": "0"}, 1000);
                    }
                });
    
    jq('#portal-searchbox #nolivesearchGadget').focus(
            function(){
                var title = jq('#parent-fieldname-title').text();
                if(jq.trim(title) == jq('#portal-searchbox #nolivesearchGadget').attr('value'))
                {
                    jq('.template-document_view #portal-searchbox #nolivesearchGadget').attr('value', "");
                }
            }).blur(function()
                {
                    var title = jq('#parent-fieldname-title').text();
                    if(title != "")
                    {
                        jq('#portal-searchbox #nolivesearchGadget').attr('value', jq.trim(title));
                    }
                    jq('#portal-searchbox').stop().animate({"opacity": "0"}, 1000);
                }
            );
    
});

==> plonetheme.intk-1.4.linux-x86_64.tar.gz: var/plone4_dev/Python-2.6/lib/python2.6/site-packages/plonetheme/intk/browser/javascripts/mason.js <==
//TODO: keep an array of all images and wait for all of them to check in before running masonry

jq(window).load(function(){
    jq('.template-search .searchResults .tileItem').css({"opacity": "0"});
    jq('.template-search .searchResults').masonry({columnWidth: 100, animate:true});
    jq('.template-search .searchResults .tileItem').animate({"opacity": "1"}, 200);
});

jq(window).load(function(){
    jq('.template-intk_folder_view #content .tileItem').css({"opacity": "0"});
    jq('.template-intk_folder_view #masonContainer').masonry({columnWidth: 100, animate:true});
    jq('.template-intk_folder_view #masonContainer .tileItem').animate({"opacity": "1"}, 200);
});

//Taking care of the searchbox stuff
jq(function(){
    jq('#portal-searchbox').hover(
                function() {
                    var title = jq('#parent-fieldname-title').text();
                    if(title != "")
                    {
                        jq('#portal-searchbox #nolivesearchGadget').attr('value', jq.trim(title));
                    }
                    jq(this).stop().css({"opacity": "1"});
                },
                function() {
                    if(jq('#portal-searchbox #nolivesearchGadget:focus').length == 0)
                    {
                        jq(this).stop().animate({"opacity": "0"}, 1000);
                    }
                });
    
    jq('#portal-searchbox #nolivesearchGadget').focus(
            function(){
                var title = jq('#parent-fieldname-title').text();
                if(jq.trim(title) == jq('#portal-searchbox #nolivesearchGadget').attr('value'))
                {
                    jq('.template-document_view #portal-searchbox #nolivesearchGadget').attr('value', "");
                }
            }).blur(function()
                {
                    var title = jq('#parent-fieldname-title').text();
                    if(title != "")
                    {
                        jq('#portal-searchbox #nolivesearchGadget').attr('value', jq.trim(title));
                    }
                    jq('#portal-searchbox').stop().animate({"opacity": "0"}, 1000);
                }
            );
});
